@@ -14,6 +14,7 @@ import (
 	"io"
 	"io/fs"
 	"log/slog"
+	"maps"
 	"net/http"
 	"net/url"
 	"os"
@@ -23,7 +24,6 @@ import (
 	"regexp"
 	"runtime"
 	"slices"
-	"sort"
 	"strings"
 	"sync"
 	"syscall"
@@ -35,7 +35,6 @@ import (
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoierrors"
 	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
-	"github.com/twpayne/chezmoi/v2/internal/chezmoimaps"
 	"github.com/twpayne/chezmoi/v2/internal/chezmoiset"
 )
 
@@ -366,8 +365,7 @@ func (s *SourceState) Add(
 	options *AddOptions,
 ) error {
 	// Filter out excluded and ignored paths.
-	destAbsPaths := AbsPaths(chezmoimaps.Keys(destAbsPathInfos))
-	sort.Sort(destAbsPaths)
+	destAbsPaths := slices.Sorted(maps.Keys(destAbsPathInfos))
 	n := 0
 	for _, destAbsPath := range destAbsPaths {
 		destAbsPathInfo := destAbsPathInfos[destAbsPath]
@@ -635,14 +633,8 @@ DEST_ABS_PATH:
 	// Rename directories last because updates assume that directory names have
 	// not changed. Rename directories in reverse order so children are renamed
 	// before their parents.
-	oldDirAbsPaths := make([]AbsPath, 0, len(dirRenames))
-	for oldDirAbsPath := range dirRenames {
-		oldDirAbsPaths = append(oldDirAbsPaths, oldDirAbsPath)
-	}
-	sort.Slice(oldDirAbsPaths, func(i, j int) bool {
-		return oldDirAbsPaths[j].Less(oldDirAbsPaths[i])
-	})
-	for _, oldDirAbsPath := range oldDirAbsPaths {
+	oldDirAbsPaths := slices.Sorted(maps.Keys(dirRenames))
+	for _, oldDirAbsPath := range slices.Backward(oldDirAbsPaths) {
 		newDirAbsPath := dirRenames[oldDirAbsPath]
 		if err := sourceSystem.Rename(oldDirAbsPath, newDirAbsPath); err != nil {
 			return err
@@ -806,9 +798,10 @@ type ExecuteTemplateDataOptions struct {
 // ExecuteTemplateData returns the result of executing template data.
 func (s *SourceState) ExecuteTemplateData(options ExecuteTemplateDataOptions) ([]byte, error) {
 	templateOptions := options.TemplateOptions
+	templateOptions.Funcs = s.templateFuncs
 	templateOptions.Options = slices.Clone(s.templateOptions)
 
-	tmpl, err := ParseTemplate(options.Name, options.Data, s.templateFuncs, templateOptions)
+	tmpl, err := ParseTemplate(options.Name, options.Data, templateOptions)
 	if err != nil {
 		return nil, err
 	}
@@ -854,9 +847,9 @@ func (s *SourceState) Ignore(targetRelPath RelPath) bool {
 }
 
 // Ignored returns all ignored RelPaths.
-func (s *SourceState) Ignored() RelPaths {
-	relPaths := RelPaths(s.ignoredRelPaths.Elements())
-	sort.Sort(relPaths)
+func (s *SourceState) Ignored() []RelPath {
+	relPaths := s.ignoredRelPaths.Elements()
+	slices.SortFunc(relPaths, CompareRelPaths)
 	return relPaths
 }
 
@@ -875,7 +868,7 @@ func (s *SourceState) PostApply(
 	targetSystem System,
 	persistentState PersistentState,
 	targetDirAbsPath AbsPath,
-	targetRelPaths RelPaths,
+	targetRelPaths []RelPath,
 ) error {
 	// Remove empty directories with the remove_ attribute. This assumes that
 	// targetRelPaths is already sorted and iterates in reverse order so that
@@ -1080,11 +1073,11 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 	}
 
 	// Read externals.
-	externalRelPaths := make(RelPaths, 0, len(s.externals))
+	externalRelPaths := make([]RelPath, 0, len(s.externals))
 	for externalRelPath := range s.externals {
 		externalRelPaths = append(externalRelPaths, externalRelPath)
 	}
-	sort.Sort(externalRelPaths)
+	slices.SortFunc(externalRelPaths, CompareRelPaths)
 	for _, externalRelPath := range externalRelPaths {
 		if s.Ignore(externalRelPath) {
 			continue
@@ -1189,7 +1182,7 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 	}
 
 	// Generate SourceStateCommands for git-repo externals.
-	var gitRepoExternalRelPaths RelPaths
+	var gitRepoExternalRelPaths []RelPath
 	for externalRelPath, externals := range s.externals {
 		if s.Ignore(externalRelPath) {
 			continue
@@ -1200,7 +1193,7 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 			}
 		}
 	}
-	sort.Sort(gitRepoExternalRelPaths)
+	slices.SortFunc(gitRepoExternalRelPaths, CompareRelPaths)
 	for _, externalRelPath := range gitRepoExternalRelPaths {
 		for _, external := range s.externals[externalRelPath] {
 			destAbsPath := s.destDirAbsPath.Join(externalRelPath)
@@ -1265,11 +1258,11 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 
 	// Check for inconsistent source entries. Iterate over the target names in
 	// order so that any error is deterministic.
-	targetRelPaths := make(RelPaths, 0, len(allSourceStateEntries))
+	targetRelPaths := make([]RelPath, 0, len(allSourceStateEntries))
 	for targetRelPath := range allSourceStateEntries {
 		targetRelPaths = append(targetRelPaths, targetRelPath)
 	}
-	sort.Sort(targetRelPaths)
+	slices.SortFunc(targetRelPaths, CompareRelPaths)
 	errs := make([]error, 0, len(targetRelPaths))
 	for _, targetRelPath := range targetRelPaths {
 		sourceStateEntries := allSourceStateEntries[targetRelPath]
@@ -1277,11 +1270,11 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 			continue
 		}
 
-		origins := make([]string, 0, len(sourceStateEntries))
-		for _, sourceStateEntry := range sourceStateEntries {
-			origins = append(origins, sourceStateEntry.Origin().OriginString())
+		origins := make([]string, len(sourceStateEntries))
+		for i, sourceStateEntry := range sourceStateEntries {
+			origins[i] = sourceStateEntry.Origin().OriginString()
 		}
-		sort.Strings(origins)
+		slices.Sort(origins)
 		errs = append(errs, &inconsistentStateError{
 			targetRelPath: targetRelPath,
 			origins:       origins,
@@ -1306,17 +1299,11 @@ func (s *SourceState) TargetRelPaths() []RelPath {
 	for targetRelPath := range entries {
 		targetRelPaths = append(targetRelPaths, targetRelPath)
 	}
-	sort.Slice(targetRelPaths, func(i, j int) bool {
-		orderI := entries[targetRelPaths[i]].Order()
-		orderJ := entries[targetRelPaths[j]].Order()
-		switch {
-		case orderI < orderJ:
-			return true
-		case orderI == orderJ:
-			return targetRelPaths[i].Less(targetRelPaths[j])
-		default:
-			return false
+	slices.SortFunc(targetRelPaths, func(a, b RelPath) int {
+		if compare := cmp.Compare(entries[a].Order(), entries[b].Order()); compare != 0 {
+			return compare
 		}
+		return CompareRelPaths(a, b)
 	})
 	return targetRelPaths
 }
@@ -1543,7 +1530,8 @@ func (s *SourceState) addTemplatesDir(ctx context.Context, templatesDirAbsPath A
 			templateRelPath := templateAbsPath.MustTrimDirPrefix(templatesDirAbsPath)
 			name := templateRelPath.String()
 
-			tmpl, err := ParseTemplate(name, contents, s.templateFuncs, TemplateOptions{
+			tmpl, err := ParseTemplate(name, contents, TemplateOptions{
+				Funcs:   s.templateFuncs,
 				Options: slices.Clone(s.templateOptions),
 			})
 			if err != nil {
@@ -1969,14 +1957,10 @@ func (s *SourceState) newModifyTargetStateEntryFunc(
 				sourceFile := sourceRelPath.String()
 				templateContents := removeMatches(modifierContents, matches)
 				var tmpl *Template
-				tmpl, err = ParseTemplate(
-					sourceFile,
-					templateContents,
-					s.templateFuncs,
-					TemplateOptions{
-						Options: slices.Clone(s.templateOptions),
-					},
-				)
+				tmpl, err = ParseTemplate(sourceFile, templateContents, TemplateOptions{
+					Funcs:   s.templateFuncs,
+					Options: slices.Clone(s.templateOptions),
+				})
 				if err != nil {
 					return
 				}
